/*

Copyright (c) 2024 Byron Lathi

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

*/

// Language: Verilog 2001

`resetall
`timescale 1ns / 1ps
`default_nettype none

/*
 * Data Modifier element
 */
module modifier #(
    parameter WIDTH = 32
)
(
    input  wire [WIDTH-1:0]     modifier,
    input  wire [WIDTH-1:0]     mask,
    input  wire [WIDTH-1:0]     data_in,
    input  wire                 enable,
    output wire [WIDTH-1:0]     data_out
);

wire [WIDTH-1:0] masked_mod;
wire [WIDTH-1:0] masked_data;

assign masked_mod = modifier & mask;
assign masked_data = data_in & ~mask;

assign data_out = enable ? (masked_mod | masked_data) : data_in;

endmodule